@@ -195,9 +195,12 @@ mgui <- function( func,
                   argOption=NULL, argFilename=NULL, argList=NULL, argSlider=NULL,
                   argCommand=NULL, argEdit=NULL, argFilter=NULL,
                   argText=NULL, argType=NULL,
-                  argGridOrder=1:length(formals(func)), sticky="nws",
+                  argGridOrder=1:length(formals(func)),
+                   argGridSticky=rep("a",length(formals(func))),
+                   argGridFrame=rep("f",length(formals(func))),
                   title=NULL,
-                  exec="Calculate ...",
+                  exec="OK",
+                  closeOnExec=is.null(output), cancelButton=TRUE,
                   callback=NULL,
                   output='m',
                   helps='auto', helpsFunc=NULL,
@@ -215,9 +218,12 @@ mgui <- function( func,
                       argOption=argOption, argFilename=argFilename, argList=argList, argSlider=argSlider,
                       argCommand=argCommand, argEdit=argEdit, argFilter=argFilter,
                       argText=argText, argType=argType,
-                      argGridOrder=argGridOrder, sticky=sticky,
+                      argGridOrder=argGridOrder,
+                       argGridSticky=argGridSticky,
+                       argGridFrame=argGridFrame,
                       title=title[length(title)],
                       exec=exec,
+                      closeOnExec=closeOnExec, cancelButton=cancelButton,
                       callback=callback,
                       output=output,
                       helps=helps, helpsFunc=helpsFunc,
